from lfinancial.generators.document_type import IDCodeGenerator


class GeneratorFactory:
    def __init__(self):
        self.generators = {
            'SSN': IDCodeGenerator(),
            'IDCard': IDCodeGenerator(),
            'Passport': IDCodeGenerator(),
            'NRIC': IDCodeGenerator(),
            'MyNumber': IDCodeGenerator(),
        }

    def register_generator(self, name, generator):
        self.generators[name] = generator

    def create_generator(self, name):
        if name in self.generators:
            return self.generators[name]
        raise ValueError(f"Unsupported generator: {name}.")



from lfinancial.factory import GeneratorFactory


class Financial:
    def __init__(self):
        self._generator_factory = GeneratorFactory()

    def _generate(self, generator_name, country):
        generator = self._generator_factory.create_generator(generator_name)
        return generator.generate_id(generator_name, country)

    def ssn(self, country=None):
        return self._generate('SSN', country)

    def id_card(self, country=None):
        return self._generate('IDCard', country)

    def passport(self, country=None):
        return self._generate('Passport', country)

    def nric(self, country=None):
        return self._generate('NRIC', country)

    def my_number(self, country=None):
        return self._generate('MyNumber', country)


if __name__ == '__main__':
    f = Financial()
    print(f.ssn())
    print(f.id_card())
    print(f.passport())
    print(f.nric())
    print(f.my_number())



from unittest import TestCase

from lfinancial import Financial
from lfinancial.generators.document_type import SSN

financial = Financial()


class TestSSN(TestCase):

    def test_generate_id(self):
        ssn = financial.ssn()
        assert len(ssn) == 11
        assert SSN._is_valid_ssn(ssn)



from setuptools import setup

excluded_packages = ["docs", "tests", "tests.*"]
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


setup(
    name='lfinancial',
    version='0.1.1',
    author='zaneliu',
    description='Generate financial test data',
    long_description=long_description,
    long_description_content_type="text/markdown",
    readme="README.md",
    author_email='lzy291980138@163.com',
    packages=['lfinancial'],
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Operating System :: OS Independent',
    ],
)
